IdTree
======

.. currentmodule:: dash_component_template.idtree

.. autoclass:: IdTree
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~IdTree.id
      ~IdTree.idbase

   .. rubric:: Attributes Documentation

   .. autoattribute:: id
   .. autoattribute:: idbase
